class Error(Exception):
    pass


class AuthError(Error):
    pass


class VKAuthError(Error):
    def __init__(self, error: dict, *args):
        super().__init__(error, *args)

    def __getitem__(self, item):
        return self.args[0].__getitem__(item)


class VKAPIError(Error):
    def __init__(self, error: dict, *args):
        super().__init__(error, *args)

    def __getitem__(self, item):
        return self.args[0].__getitem__(item)

    def __str__(self):
        return (f'Error {self["error_code"]}: {self["error_msg"]}. '
                f'Parameters: {self["request_params"]}')



PERMISSIONS = (
    # 'notify',  # leads to unsupported access form
    'friends',
    'photos',
    'audio',
    'video',
    'stories',
    'pages',
    'status',
    'notes',
    # 'messages',  # available only after moderation
    'wall',
    'offline',
    'docs',
    'groups',
    'notifications',
    'stats',
    'email',
    'market',
)

BITMASKS = {
    'notify': 1,
    'friends': 2,
    'photos': 4,
    'audio': 8,
    'video': 16,
    'stories': 64,
    'pages': 128,
    'status': 1024,
    'notes': 2048,
    'messages': 4096,
    'wall': 8192,
    'offline': 65536,
    'docs': 131072,
    'groups': 262144,
    'notifications': 524288,
    'stats': 1048576,
    'email': 4194304,
    'market': 134217728,
}


def bit_scope(permissions):
    return sum(BITMASKS[p] for p in permissions)



from . import api, exceptions, parsers, sessions
from .exceptions import AuthError, VKAuthError, VKAPIError
from .sessions import TokenSession, ImplicitSession
from .api import API

import logging


logging.basicConfig()
